from django.db import models

## Some advices
##
## * Make sure that your data models are right before coding anything else
##
## * Develop using a sqlite database to assure portability between the
##   development copy and the production copy

class Category(models.Model):
    name = models.CharField("Category name",max_length=100,unique=True)
    description = models.TextField("Description",blank=True)

    def __str__(self):
        return self.name
    
    def __unicode__(self):
        return self.name

    class Meta:
        verbose_name = "Category"
        verbose_name_plural = "Categories"

    class Admin:
        pass


class Tag(models.Model):
    name = models.CharField("Tag name",max_length=100,unique=True)
    description = models.TextField("Description",blank=True)

    def __str__(self):
        return self.name
    
    def __unicode__(self):
        return self.name

    class Admin:
        pass


class Author(models.Model):
    name = models.CharField("Name",max_length=200,unique=True)
    email = models.EmailField("Author's email")

    def __str__(self):
        return self.name
    
    def __unicode__(self):
        return self.name

    class Admin:
        pass


class Entry(models.Model):
    title = models.CharField("Title",max_length=200)
    slug = models.SlugField(prepopulate_from=("title",),unique=True)
    author = models.ForeignKey(Author)
    date = models.DateTimeField()
    foreword = models.TextField("Foreword")
    body = models.TextField("Entry body",blank=True)
    category = models.ForeignKey(Category)
    tags = models.ManyToManyField(Tag)
    related = models.ManyToManyField("self",blank=True)
    published = models.BooleanField("Published?")

    def __str__(self):
        return self.title
    
    def __unicode__(self):
        return self.title

    def get_absolute_url(self):
        return '/guillem/blog/%s/'%(self.slug)

    def ncomments(self):
        comments = Comment.objects.filter(entry__slug=self.slug)
        return len(comments)

    class Meta:
        verbose_name = "Entry"
        verbose_name_plural = "Entries"

    class Admin:
        pass


class Comment(models.Model):
    title = models.CharField("Title",max_length=100)
    author = models.CharField("Author",max_length=100)
    author_email = models.EmailField("Email",max_length=100)
    author_web = models.URLField("Web page",blank=True)
    entry = models.ForeignKey(Entry)
    karma = models.SmallIntegerField("karma")#remeber to start this
                                             #with zero value
    date = models.DateTimeField(auto_now_add=True)
    body = models.TextField("Comment body")

    def __str__(self):
        return self.title+' by '+self.author
    
    def __unicode__(self):
        return self.title+' by '+self.author

    class Admin:
        pass

class sidebar(models.Model):#Gilipollas, esto tendria que ir en
                            #CamelCase
    title = models.CharField("Title", max_length=100)
    body = models.TextField("Body")

    def __str__(self):
        return self.title

    def __unicode__(self):
        return self.title

    class Admin:
        pass


class Top(models.Model):
    entry = models.ForeignKey(Entry)

    def get_absolute_url(self):
        pass

    def __str__(self):
        return self.entry.title

    def __unicode__(self):
        return self.entry.title

    class Admin:
        pass
